@@ -5,7 +5,7 @@ from .distribution import Distribution
 
 class BranchLenInterpolator (Distribution):
     """
-    Tjis class defines the methods to manipulate the branch length probability
+    This class defines the methods to manipulate the branch length probability
     distributions.
 
     """
@@ -149,7 +149,7 @@ class BranchLenInterpolator (Distribution):
         return res
 
     def __mul__(self, other):
-        res = BranchLenInterpolator(super(BranchLenInterpolator, self).__mul__(other))
+        res = BranchLenInterpolator(super(BranchLenInterpolator, self).__mul__(other), gtr=self.gtr)
         return res
 
 
