@@ -6,8 +6,10 @@ import numpy as np
 import scipy.special as sf
 from scipy.interpolate import interp1d
 from Bio import AlignIO, Phylo
-from scipy.interpolate import interp1d
-from collections import Iterable
+try:
+    from collections.abc import Iterable
+except ImportError:
+    from collections import Iterable
 from treetime import config as ttconf
 
 
@@ -215,6 +217,7 @@ class Coalescent(object):
             self.logger("Coalescent:optimize_skyline:...done. new LH: %f"%self.total_LH(),2)
         else:
             self.set_Tc(initial_Tc.y, T=initial_Tc.x)
+            self.confidence = [np.nan for i in initial_Tc.x]
             self.logger("Coalescent:optimize_skyline:...failed:"+str(sol),0, warn=True)
 
 
@@ -274,4 +277,4 @@ class Coalescent(object):
             conf = [skyline.y*np.exp(-confidence*self.confidence), skyline.y*np.exp(confidence*self.confidence)]
             return skyline, conf
         else:
-            return skyline
+            return skyline, None
