@@ -121,16 +121,15 @@ def _max_of_integrand(t_val, f, g, inverse_time=None, return_log=False):
     FG = _convolution_integrand(t_val, f, g, inverse_time, return_log=True)
 
     if FG == ttconf.BIG_NUMBER:
-        res = ttconf.BIG_NUMBER, 0
+        res = [ttconf.BIG_NUMBER, 0]
 
     else:
         X = FG.x[FG.y.argmin()]
         Y = FG.y.min()
-        res =  Y, X
+        res =  [Y, X]
 
     if not return_log:
-        res[0] = np.log(res[0])
-
+        res[0] = np.exp(res[0])
 
     return res
 
@@ -166,7 +165,7 @@ class NodeInterpolator (Distribution):
                  n_grid_points = ttconf.NODE_GRID_SIZE, n_integral=ttconf.N_INTEGRAL,
                  inverse_time=True, rel_tol=0.05, yc=10):
 
-        '''
+        r'''
         calculate H(t) = \int_tau f(t-tau)g(tau) if inverse_time=True
                   H(t) = \int_tau f(t+tau)g(tau) if inverse_time=False
 
@@ -279,4 +278,3 @@ class NodeInterpolator (Distribution):
                              min_width=node_interp.min_width, kind='linear')
 
         return res_y, res_t
-
