@@ -13,10 +13,10 @@ class SeqGen(TreeAnc):
     This class inherits from TreeAnc.
     '''
 
-    def __init__(self, *args, **kwargs):
-        """Instantiate. Mandatory arguments are a tree and GTR model.
+    def __init__(self, L, *args, **kwargs):
+        """Instantiate. Mandatory arguments are a the sequence length, tree and GTR model.
         """
-        super(SeqGen, self).__init__(reduce_alignment=False, **kwargs)
+        super(SeqGen, self).__init__(seq_len=L, compress=False, **kwargs)
 
 
     def sample_from_profile(self, p):
@@ -50,30 +50,23 @@ class SeqGen(TreeAnc):
             sequence to be used as the root sequence of the tree. if not given,
             will sample a sequence from the equilibrium probabilities of the GTR model.
         """
-        self.seq_len = self.gtr.seq_len
         # set root if not given
         if root_seq:
-            self.tree.root.sequence = seq2array(root_seq)
+            self.tree.root.ancestral_sequence = seq2array(root_seq)
         else:
             if len(self.gtr.Pi.shape)==2:
-                self.tree.root.sequence = self.sample_from_profile(self.gtr.Pi.T)
+                self.tree.root.ancestral_sequence = self.sample_from_profile(self.gtr.Pi.T)
             else:
-                self.tree.root.sequence = self.sample_from_profile(np.repeat([self.gtr.Pi], self.seq_len, axis=0))
+                self.tree.root.ancestral_sequence = self.sample_from_profile(np.repeat([self.gtr.Pi], self.seq_len, axis=0))
 
         # generate sequences in preorder
         for n in self.tree.get_nonterminals(order='preorder'):
-            profile_p = seq2prof(n.sequence, self.gtr.profile_map)
+            profile_p = seq2prof(n.ancestral_sequence, self.gtr.profile_map)
             for c in n:
                 profile = self.gtr.evolve(profile_p, c.branch_length)
-                c.sequence = self.sample_from_profile(profile)
-        self.make_reduced_alignment()
+                c.ancestral_sequence = self.sample_from_profile(profile)
 
-        # gather mutations
-        for n in self.tree.find_clades():
-            if n==self.tree.root:
-                n.mutations=[]
-            else:
-                n.mutations = self.get_mutations(n)
+        self.aln = self.get_aln()
 
 
     def get_aln(self, internal=False):
@@ -96,7 +89,7 @@ class SeqGen(TreeAnc):
         tmp = []
         for n in self.tree.get_terminals():
             if n.is_terminal() or internal:
-                tmp.append(SeqRecord.SeqRecord(id=n.name, name=n.name, description='', seq=Seq.Seq(''.join(n.sequence))))
+                tmp.append(SeqRecord.SeqRecord(id=n.name, name=n.name, description='', seq=Seq.Seq(''.join(n.ancestral_sequence.astype('U')))))
 
         return MultipleSeqAlignment(tmp)
 
