@@ -161,11 +161,11 @@ class SequenceData(object):
 
         if type(in_aln) is MultipleSeqAlignment:
             # check whether the alignment is consistent with a nucleotide alignment.
-            self.check_alphabet([seq2array(s) for s in in_aln])
-            self.is_sparse = False
             self._aln = {s.name: seq2array(s, convert_upper=self.convert_upper,
                                            fill_overhangs=self.fill_overhangs, ambiguous=self.ambiguous)
                          for s in in_aln}
+            self.check_alphabet(list(self._aln.values()))
+            self.is_sparse = False
             self.logger("SequenceData: loaded alignment.",1)
         elif type(in_aln) in [dict, defaultdict]:
             self.logger("SequenceData: loaded sparse/vcf alignment.",1)
@@ -334,6 +334,7 @@ class SequenceData(object):
                 pattern = np.array([self.aln[k][pi] if pi in self.aln[k] else self.ref[pi]
                            for k in self.sequence_names], dtype='S')
             else:
+                # pylint: disable=unsubscriptable-object
                 pattern = np.copy(aln_transpose[pi])
 
             # if the column contains only one state and ambiguous nucleotides, replace
@@ -396,6 +397,7 @@ class SequenceData(object):
 
         # create the compressed alignment as a dictionary linking names to sequences
         tmp_compressed_alignment = np.array(compressed_aln_transpose).T
+        # pylint: disable=unsubscriptable-object
         self.compressed_alignment = {k: tmp_compressed_alignment[i]
                                   for i,k in enumerate(self.sequence_names)}
 
