@@ -19,7 +19,7 @@ def compressed_sequence(node):
     elif hasattr(node, '_cseq'):
         return node._cseq
     elif node.is_terminal(): # node without sequence when tip-reconstruction is off.
-            return None
+        return None
     elif hasattr(node, '_cseq'):
         return node._cseq
     else:
@@ -225,7 +225,7 @@ class TreeAnc(object):
          value : GTR
             the new GTR object
         """
-        if not (isinstance(value, GTR) or isinstance(value, GTR_site_specific)):
+        if not isinstance(value, (GTR, GTR_site_specific)):
             raise TypeError("GTR instance expected")
         self._gtr = value
 
@@ -250,8 +250,7 @@ class TreeAnc(object):
         if isinstance(in_gtr, str):
             self._gtr = GTR.standard(model=in_gtr, **kwargs)
             self._gtr.logger = self.logger
-
-        elif isinstance(in_gtr, GTR) or isinstance(in_gtr, GTR_site_specific):
+        elif isinstance(in_gtr, (GTR, GTR_site_specific)):
             self._gtr = in_gtr
             self._gtr.logger=self.logger
         else:
@@ -378,7 +377,7 @@ class TreeAnc(object):
                 self.logger("***WARNING: TreeAnc._attach_sequences_to_nodes: NO SEQUENCE FOR LEAF: %s" % l.name, 0, warn=True)
                 failed_leaves += 1
                 if failed_leaves > self.tree.count_terminals()/3:
-                    raise MissingDataError("TreeAnc._check_alignment_tree_gtr_consistency: At least 30\% terminal nodes cannot be assigned a sequence!\n"
+                    raise MissingDataError("TreeAnc._check_alignment_tree_gtr_consistency: At least 30\\% terminal nodes cannot be assigned a sequence!\n"
                                            "Are you sure the alignment belongs to the tree?")
             else: # could not assign sequence for internal node - is OK
                 pass
@@ -415,7 +414,7 @@ class TreeAnc(object):
         self.tree.root.tt = self
         self.tree.root.bad_branch=self.tree.root.bad_branch if hasattr(self.tree.root, 'bad_branch') else False
 
-        name_set = set([n.name for n in self.tree.find_clades() if n.name])
+        name_set = {n.name for n in self.tree.find_clades() if n.name}
         internal_node_count = 0
         for clade in self.tree.get_nonterminals(order='preorder'): # parents first
             if clade.name is None:
@@ -783,6 +782,7 @@ class TreeAnc(object):
 
         self.tree.sequence_LH = marginal_LH_prefactor
         self.tree.total_sequence_LH = (self.tree.sequence_LH*self.data.multiplicity).sum()
+        self.tree.sequence_marginal_LH = self.tree.total_sequence_LH
         if assign_sequence:
             seq, prof_vals, idxs = prof2seq(self.tree.root.marginal_profile,
                                         self.gtr, sample_from_prof=sample_from_profile, normalize=False)
@@ -1018,7 +1018,7 @@ class TreeAnc(object):
 
         # expand to full sequence if requested
         if full_sequence:
-            return mut_matrix_stack[self.full_to_compressed_sequence_map]
+            return mut_matrix_stack[self.data.full_to_compressed_sequence_map]
         else:
             return mut_matrix_stack
 
@@ -1185,7 +1185,7 @@ class TreeAnc(object):
 
 
     def optimize_tree_marginal(self, max_iter=10, infer_gtr=False, pc=1.0, damping=0.75,
-                               LHtol=0.1, site_specific_gtr=False):
+                               LHtol=0.1, site_specific_gtr=False, **kwargs):
         self.infer_ancestral_sequences(marginal=True)
         oldLH = self.sequence_LH()
         self.logger("TreeAnc.optimize_tree_marginal: initial, LH=%1.2f, total branch_length %1.4f"%
@@ -1289,6 +1289,7 @@ class TreeAnc(object):
             self.optimize_tree_marginal(max_iter=max_iter, infer_gtr=infer_gtr, pc=pc, **kwargs)
             if prune_short:
                 self.prune_short_branches()
+            return ttconf.SUCCESS
         elif branch_length_mode=='input':
             N_diff = self.reconstruct_anc(method='probabilistic', infer_gtr=infer_gtr, pc=pc,
                                           marginal=marginal_sequences, **kwargs)
@@ -1610,8 +1611,10 @@ class TreeAnc(object):
         else:
             if (not reconstructed) and (node.name in self.data.aln):
                 tmp_seq = self.data.aln[node.name]
-            else:
+            elif node.cseq is not None:
                 tmp_seq = self.data.compressed_to_full_sequence(node.cseq, as_string=False)
+            else:
+                tmp_seq = np.array([self.gtr.ambiguous or 'N']*self.data.compressed_length)
 
         return "".join(tmp_seq) if as_string else np.copy(tmp_seq)
 
@@ -1626,4 +1629,3 @@ class TreeAnc(object):
             self.logger("Your code reconstructed tip states, please change the call of ancestral inference in your code",0, warn=True)
         else:
             self.logger("Your analysis did not reconstructed tip states, you can remove the call of `recover_var_ambigs`",0, warn=True)
-
