@@ -338,7 +338,7 @@ class TreeRegression(object):
             bv = self.branch_value(n)
             var = self.branch_variance(n)
             x, chisq = self._optimal_root_along_branch(n, tv, bv, var, slope=slope)
-            if (chisq<best_root["chisq"]):
+            if chisq<best_root["chisq"]:
                 tmpQ = self.propagate_averages(n, tv, bv*x, var*x) \
                      + self.propagate_averages(n, tv, bv*(1-x), var*(1-x), outgroup=True)
                 reg = base_regression(tmpQ, slope=slope)
@@ -575,7 +575,7 @@ if __name__ == '__main__':
     #T.root_with_outgroup('A/Canterbury/58/2000|CY009150|09/05/2000|New_Zealand||H3N2/8-1416')
 
     dates = {}
-    with open(date_file) as ifile:
+    with open(date_file, 'r', encoding='utf-8') as ifile:
         ifile.readline()
         for line in ifile:
             if line[0]!='#':
