@@ -126,13 +126,14 @@ class TreeTime(ClockTree):
 
         if (self.tree is None) or (self.aln is None and self.data.full_length is None):
             raise MissingDataError("TreeTime.run: ERROR, alignment or tree are missing")
-        if (self.aln is None):
+        if self.aln is None:
             branch_length_mode='input'
 
         self._set_branch_length_mode(branch_length_mode)
 
         # determine how to reconstruct and sample sequences
         seq_kwargs = {"marginal_sequences":sequence_marginal or (self.branch_length_mode=='marginal'),
+                      "branch_length_mode": self.branch_length_mode,
                       "sample_from_profile":"root",
                       "reconstruct_tip_states":kwargs.get("reconstruct_tip_states", False)}
 
@@ -148,7 +149,7 @@ class TreeTime(ClockTree):
         # initially, infer ancestral sequences and infer gtr model if desired
         if self.branch_length_mode=='input':
             if self.aln:
-                self.infer_ancestral_sequences(infer_gtr=infer_gtr, **seq_kwargs)
+                self.infer_ancestral_sequences(infer_gtr=infer_gtr, marginal=seq_kwargs["marginal_sequences"], **seq_kwargs)
                 self.prune_short_branches()
         else:
             self.optimize_tree(infer_gtr=infer_gtr,
@@ -259,8 +260,8 @@ class TreeTime(ClockTree):
         bad_branches =[n for n in self.tree.get_terminals()
                        if n.bad_branch and n.raw_date_constraint]
         if bad_branches:
-            self.logger("TreeTime: The following tips don't fit the clock model, "
-                        "please remove them from the tree. Their dates have been reset:",0,warn=True)
+            self.logger("TreeTime: the following tips have been marked as outliers. Their date constraints were not used. "
+                        "Please remove them from the tree. Their dates have been reset:",0,warn=True)
             for n in bad_branches:
                 self.logger("%s, input date: %s, apparent date: %1.2f"%(n.name, str(n.raw_date_constraint), n.numdate),0,warn=True)
 
@@ -295,7 +296,7 @@ class TreeTime(ClockTree):
 
 
     def clock_filter(self, reroot='least-squares', n_iqd=None, plot=False, fixed_clock_rate=None):
-        '''
+        r'''
         Labels outlier branches that don't seem to follow a molecular clock
         and excludes them from subsequent molecular clock estimation and
         the timetree propagation.
@@ -441,7 +442,7 @@ class TreeTime(ClockTree):
             if isinstance(root,Phylo.BaseTree.Clade):
                 new_root = root
             elif isinstance(root, list):
-                new_root = self.tree.common_ancestor(*root)
+                new_root = self.tree.common_ancestor(root)
             elif root in self._leaves_lookup:
                 new_root = self._leaves_lookup[root]
             elif root=='oldest':
@@ -607,8 +608,15 @@ class TreeTime(ClockTree):
                     self.add_branch_state(new_node)
 
                 new_node.mutation_length = 0.0
-                new_node.branch_length_interpolator = BranchLenInterpolator(new_node, self.gtr, one_mutation=self.one_mutation,
-                                                                            branch_length_mode = self.branch_length_mode)
+                if self.branch_length_mode=='marginal':
+                    new_node.marginal_subtree_LH =  clade.marginal_subtree_LH
+                    new_node.marginal_outgroup_LH = clade.marginal_outgroup_LH
+                    new_node.profile_pair = self.marginal_branch_profile(new_node)
+
+                new_node.branch_length_interpolator = BranchLenInterpolator(new_node, self.gtr,
+                            pattern_multiplicity = self.data.multiplicity, min_width=self.min_width,
+                            one_mutation=self.one_mutation, branch_length_mode=self.branch_length_mode)
+
                 clade.clades.remove(n1)
                 clade.clades.remove(n2)
                 clade.clades.append(new_node)
@@ -911,5 +919,3 @@ def treetime_to_newick(tt, outf):
 
 if __name__=="__main__":
     pass
-
-
